@@ -377,11 +377,12 @@ void faust_make_json(t_faust* x)
 void* faust_new(t_symbol* s, short ac, t_atom* av)
 {
     bool midi_sync = false;
+    bool midi = false;
     int nvoices = 0;
     t_faust* x = (t_faust*)object_alloc(faust_class);
     
     mydsp* tmp_dsp = new mydsp();
-    MidiMeta::analyse(tmp_dsp, midi_sync, nvoices);
+    MidiMeta::analyse(tmp_dsp, midi, midi_sync, nvoices);
 #ifdef SOUNDFILE
     Max_Meta3 meta3;
     tmp_dsp->metadata(&meta3);
@@ -630,10 +631,7 @@ t_int* faust_perform(t_int* w)
     if (!x->m_mute && systhread_mutex_trylock(x->m_mutex) == MAX_ERR_NONE) {
         if (x->m_dsp) {
             x->m_dsp->compute(n, ((float**)&w[offset]), ((float**)&w[offset + x->m_dsp->getNumInputs()]));
-        #ifdef OSCCTRL
-            if (x->m_oscInterface) x->m_oscInterface->endBundle();
-        #endif
-            //faust_update_outputs(x);
+            // faust_update_outputs(x);
             // Use the right outlet to output messages
             faust_dump_outputs(x);
         }
