@@ -128,7 +128,7 @@ static string wdel(const string& s)
 void Compiler::generateMetaData()
 {
     // Add global metadata
-    for (map<Tree, set<Tree> >::iterator i = gGlobal->gMetaDataSet.begin();
+    for (map<Tree, set<Tree, CTreeComparator>>::iterator i = gGlobal->gMetaDataSet.begin();
          i != gGlobal->gMetaDataSet.end(); i++) {
         if (i->first != tree("author")) {
             stringstream str1, str2;
@@ -138,7 +138,8 @@ void Compiler::generateMetaData()
             string res2 = unquote(str2.str());
             fJSON.declare(res1.c_str(), res2.c_str());
         } else {
-            for (set<Tree>::iterator j = i->second.begin(); j != i->second.end(); j++) {
+            for (set<Tree, CTreeComparator>::iterator j = i->second.begin(); j != i->second.end();
+                 j++) {
                 if (j == i->second.begin()) {
                     stringstream str1, str2;
                     str1 << *(i->first);
@@ -174,12 +175,12 @@ void Compiler::generateUserInterfaceTree(Tree t, bool root)
 
         // extract metadata from group label str resulting in a simplifiedLabel
         // and metadata declarations for fictive zone at address 0
-        string                    simplifiedLabel;
-        map<string, set<string> > metadata;
+        string                   simplifiedLabel;
+        map<string, set<string>> metadata;
         extractMetadata(str, simplifiedLabel, metadata);
 
         // add metadata if any
-        for (map<string, set<string> >::iterator i = metadata.begin(); i != metadata.end(); i++) {
+        for (map<string, set<string>>::iterator i = metadata.begin(); i != metadata.end(); i++) {
             const string&      key    = i->first;
             const set<string>& values = i->second;
             for (set<string>::const_iterator j = values.begin(); j != values.end(); j++) {
@@ -245,15 +246,15 @@ void Compiler::generateUserInterfaceElements(Tree elements)
  */
 void Compiler::generateWidgetCode(Tree fulllabel, Tree varname, Tree sig)
 {
-    Tree                      path, c, x, y, z;
-    map<string, set<string> > metadata;
-    string                    label, url;
+    Tree                     path, c, x, y, z;
+    map<string, set<string>> metadata;
+    string                   label, url;
 
     extractMetadata(tree2str(fulllabel), label, metadata);
 
     // Extract "url" metadata to be given as parameter to 'addSoundfile' function
     if (isSigSoundfile(sig, path)) {
-        for (map<string, set<string> >::iterator i = metadata.begin(); i != metadata.end(); i++) {
+        for (map<string, set<string>>::iterator i = metadata.begin(); i != metadata.end(); i++) {
             string      key    = i->first;
             set<string> values = i->second;
             for (set<string>::const_iterator j = values.begin(); j != values.end(); j++) {
@@ -264,7 +265,7 @@ void Compiler::generateWidgetCode(Tree fulllabel, Tree varname, Tree sig)
         }
     } else {
         // Add metadata if any
-        for (map<string, set<string> >::iterator i = metadata.begin(); i != metadata.end(); i++) {
+        for (map<string, set<string>>::iterator i = metadata.begin(); i != metadata.end(); i++) {
             const string&      key    = i->first;
             const set<string>& values = i->second;
             for (set<string>::const_iterator j = values.begin(); j != values.end(); j++) {
@@ -387,9 +388,9 @@ void Compiler::generateMacroInterfaceElements(const string& pathname, Tree eleme
  */
 void Compiler::generateWidgetMacro(const string& pathname, Tree fulllabel, Tree varname, Tree sig)
 {
-    Tree                      path, c, x, y, z;
-    string                    label;
-    map<string, set<string> > metadata;
+    Tree                     path, c, x, y, z;
+    string                   label;
+    map<string, set<string>> metadata;
 
     extractMetadata(tree2str(fulllabel), label, metadata);
     string pathlabel = pathname + label;
