@@ -122,7 +122,7 @@ void RustCodeContainer::produceInternal()
     // generateInstanceInitFun("instanceInit" + fKlassName, false, false)->accept(&fCodeProducer);
 
     tab(n + 1, *fOut);
-    *fOut << "fn instance_init" << fKlassName << "(&mut self, sample_rate: i32) {";
+    *fOut << "pub fn instance_init" << fKlassName << "(&mut self, sample_rate: i32) {";
     tab(n + 2, *fOut);
     fCodeProducer.Tab(n + 2);
     generateInit(&fCodeProducer);
@@ -136,12 +136,12 @@ void RustCodeContainer::produceInternal()
     string counter = "count";
     if (fSubContainerType == kInt) {
         tab(n + 1, *fOut);
-        *fOut << "fn fill" << fKlassName
+        *fOut << "pub fn fill" << fKlassName
               << subst("(&mut self, $0: i32, table: &mut[i32]) {", counter);
     } else {
         tab(n + 1, *fOut);
-        *fOut << "fn fill" << fKlassName
-              << subst("(&mut self, $0: i32, table: &mut[$1]) {", counter, ifloat());
+        *fOut << "pub fn fill" << fKlassName
+              << subst("(&mut self, $0: i32, table: &mut[FaustFloat]) {", counter);
     }
     tab(n + 2, *fOut);
     fCodeProducer.Tab(n + 2);
@@ -168,9 +168,73 @@ void RustCodeContainer::produceInternal()
     *fOut << "}";
 }
 
+void RustCodeContainer::produceFaustDspBlob()
+{
+    const char* tab = "\t";
+    *fOut << "impl FaustDsp for " << fKlassName << " {" << endl;
+    *fOut << tab << "type T = FaustFloat;" << endl;
+    *fOut << tab << "fn new() -> Self where Self: Sized {" << endl;
+    *fOut << tab << tab << "Self::new()" << endl;
+    *fOut << tab << "}" << endl;
+    *fOut << tab << "fn metadata(&self, m: &mut dyn Meta) {" << endl;
+    *fOut << tab << tab << "self.metadata(m)" << endl;
+    *fOut << tab << "}" << endl;
+    *fOut << tab << "fn get_sample_rate(&self) -> i32 {" << endl;
+    *fOut << tab << tab << "self.get_sample_rate()" << endl;
+    *fOut << tab << "}" << endl;
+    *fOut << tab << "fn get_num_inputs(&self) -> i32 {" << endl;
+    *fOut << tab << tab << "FAUST_INPUTS as i32" << endl;
+    *fOut << tab << "}" << endl;
+    *fOut << tab << "fn get_num_outputs(&self) -> i32 {" << endl;
+    *fOut << tab << tab << "FAUST_OUTPUTS as i32" << endl;
+    *fOut << tab << "}" << endl;
+    *fOut << tab << "fn class_init(sample_rate: i32) where Self: Sized {" << endl;
+    *fOut << tab << tab << "Self::class_init(sample_rate);" << endl;
+    *fOut << tab << "}" << endl;
+    *fOut << tab << "fn instance_reset_params(&mut self) {" << endl;
+    *fOut << tab << tab << "self.instance_reset_params()" << endl;
+    *fOut << tab << "}" << endl;
+    *fOut << tab << "fn instance_clear(&mut self) {" << endl;
+    *fOut << tab << tab << "self.instance_clear()" << endl;
+    *fOut << tab << "}" << endl;
+    *fOut << tab << "fn instance_constants(&mut self, sample_rate: i32) {" << endl;
+    *fOut << tab << tab << "self.instance_constants(sample_rate)" << endl;
+    *fOut << tab << "}" << endl;
+    *fOut << tab << "fn instance_init(&mut self, sample_rate: i32) {" << endl;
+    *fOut << tab << tab << "self.instance_init(sample_rate)" << endl;
+    *fOut << tab << "}" << endl;
+    *fOut << tab << "fn init(&mut self, sample_rate: i32) {" << endl;
+    *fOut << tab << tab << "self.init(sample_rate)" << endl;
+    *fOut << tab << "}" << endl;
+    *fOut << tab << "fn build_user_interface(&self, ui_interface: &mut dyn UI<Self::T>) {" << endl;
+    *fOut << tab << tab << "self.build_user_interface(ui_interface)" << endl;
+    *fOut << tab << "}" << endl;
+    *fOut
+        << tab
+        << "fn build_user_interface_static(ui_interface: &mut dyn UI<Self::T>) where Self: Sized {"
+        << endl;
+    *fOut << tab << tab << "Self::build_user_interface_static(ui_interface);" << endl;
+    *fOut << tab << "}" << endl;
+    *fOut << tab << "fn get_param(&self, param: ParamIndex) -> Option<Self::T> {" << endl;
+    *fOut << tab << tab << "self.get_param(param)" << endl;
+    *fOut << tab << "}" << endl;
+    *fOut << tab << "fn set_param(&mut self, param: ParamIndex, value: Self::T) {" << endl;
+    *fOut << tab << tab << "self.set_param(param, value)" << endl;
+    *fOut << tab << "}" << endl;
+    *fOut << tab
+          << "fn compute(&mut self, count: i32, inputs: &[&[Self::T]], outputs: &mut [&mut "
+             "[Self::T]]) {"
+          << endl;
+    *fOut << tab << tab << "self.compute(count as usize, inputs, outputs)" << endl;
+    *fOut << tab << "}" << endl;
+    *fOut << "}" << endl;
+}
+
 void RustCodeContainer::produceClass()
 {
     int n = 0;
+    tab(n, *fOut);
+    *fOut << "pub type FaustFloat = " << ifloat() << ";";
 
     // Generate gub containers
     generateSubContainers();
@@ -185,13 +249,13 @@ void RustCodeContainer::produceClass()
     if (gGlobal->gFloatSize == 1) {
         *fOut << "mod ffi {";
         tab(n + 1, *fOut);
-        *fOut << "use std::os::raw::{c_float};";
+        *fOut << "use std::os::raw::c_float;";
         tab(n + 1, *fOut);
         *fOut << "// Conditionally compile the link attribute only on non-Windows platforms";
         tab(n + 1, *fOut);
-        *fOut << "#[cfg_attr(not(target_os=\"windows\"), link(name=\"m\"))]";
+        *fOut << "#[cfg_attr(not(target_os = \"windows\"), link(name = \"m\"))]";
         tab(n + 1, *fOut);
-        *fOut << "extern {";
+        *fOut << "extern \"C\" {";
         tab(n + 2, *fOut);
         *fOut << "pub fn remainderf(from: c_float, to: c_float) -> c_float;";
         tab(n + 2, *fOut);
@@ -258,6 +322,16 @@ void RustCodeContainer::produceClass()
         */
     }
 
+    tab(n, *fOut);
+    *fOut << "pub const FAUST_INPUTS: usize = " << fNumInputs << ";";
+    tab(n, *fOut);
+    *fOut << "pub const FAUST_OUTPUTS: usize = " << fNumOutputs << ";";
+    tab(n, *fOut);
+    *fOut << "pub const FAUST_ACTIVES: usize = " << fNumActives << ";";
+    tab(n, *fOut);
+    *fOut << "pub const FAUST_PASSIVES: usize = " << fNumPassives << ";";
+    tab(n, *fOut);
+
     tab(n, *fOut);
     *fOut << "#[cfg_attr(feature = \"default-boxed\", derive(default_boxed::DefaultBoxed))]";
     if (gGlobal->gReprC) {
@@ -278,11 +352,7 @@ void RustCodeContainer::produceClass()
     tab(n, *fOut);
 
     tab(n, *fOut);
-    *fOut << "impl FaustDsp for " << fKlassName << " {";
-
-    // Associated type
-    tab(n + 1, *fOut);
-    *fOut << "type T = " << ifloat() << ";";
+    *fOut << "impl " << fKlassName << " {";
 
     // Memory methods
     tab(n + 2, *fOut);
@@ -307,7 +377,7 @@ void RustCodeContainer::produceClass()
         tab(n + 1, *fOut);
     }
 
-    *fOut << "fn new() -> " << fKlassName << " { ";
+    *fOut << "pub fn new() -> " << fKlassName << " { ";
     if (fAllocateInstructions->fCode.size() > 0) {
         tab(n + 2, *fOut);
         *fOut << "allocate" << fKlassName << "(dsp);";
@@ -325,11 +395,10 @@ void RustCodeContainer::produceClass()
     produceMetadata(n + 1);
 
     // Get sample rate method
-    tab(n + 1, *fOut);
     fCodeProducer.Tab(n + 1);
-    generateGetSampleRate("get_sample_rate", "&self", false, false)->accept(&fCodeProducer);
-
-    produceInfoFunctions(n + 1, "", "&self", false, FunTyped::kDefault, &fCodeProducer);
+    tab(n + 1, *fOut);
+    *fOut << "pub fn get_sample_rate(&self) -> i32 { self.fSampleRate as i32}";
+    tab(n + 1, *fOut);
 
     // Inits
 
@@ -341,7 +410,7 @@ void RustCodeContainer::produceClass()
     // generateInstanceInitFun("instanceInit" + fKlassName, false, false)->accept(&codeproducer2);
 
     tab(n + 1, *fOut);
-    *fOut << "fn class_init(sample_rate: i32) {";
+    *fOut << "pub fn class_init(sample_rate: i32) {";
     {
         tab(n + 2, *fOut);
         // Local visitor here to avoid DSP object type wrong generation
@@ -353,7 +422,7 @@ void RustCodeContainer::produceClass()
     *fOut << "}";
 
     tab(n + 1, *fOut);
-    *fOut << "fn instance_reset_params(&mut self) {";
+    *fOut << "pub fn instance_reset_params(&mut self) {";
     {
         tab(n + 2, *fOut);
         // Local visitor here to avoid DSP object type wrong generation
@@ -365,7 +434,7 @@ void RustCodeContainer::produceClass()
     *fOut << "}";
 
     tab(n + 1, *fOut);
-    *fOut << "fn instance_clear(&mut self) {";
+    *fOut << "pub fn instance_clear(&mut self) {";
     {
         tab(n + 2, *fOut);
         // Local visitor here to avoid DSP object type wrong generation
@@ -377,7 +446,7 @@ void RustCodeContainer::produceClass()
     *fOut << "}";
 
     tab(n + 1, *fOut);
-    *fOut << "fn instance_constants(&mut self, sample_rate: i32) {";
+    *fOut << "pub fn instance_constants(&mut self, sample_rate: i32) {";
     {
         tab(n + 2, *fOut);
         // Local visitor here to avoid DSP object type wrong generation
@@ -389,7 +458,7 @@ void RustCodeContainer::produceClass()
     *fOut << "}";
 
     tab(n + 1, *fOut);
-    *fOut << "fn instance_init(&mut self, sample_rate: i32) {";
+    *fOut << "pub fn instance_init(&mut self, sample_rate: i32) {";
     tab(n + 2, *fOut);
     *fOut << "self.instance_constants(sample_rate);";
     tab(n + 2, *fOut);
@@ -400,7 +469,7 @@ void RustCodeContainer::produceClass()
     *fOut << "}";
 
     tab(n + 1, *fOut);
-    *fOut << "fn init(&mut self, sample_rate: i32) {";
+    *fOut << "pub fn init(&mut self, sample_rate: i32) {";
     tab(n + 2, *fOut);
     *fOut << fKlassName << "::class_init(sample_rate);";
     tab(n + 2, *fOut);
@@ -417,7 +486,7 @@ void RustCodeContainer::produceClass()
     // User interface (non-static method)
     tab(n + 1, *fOut);
     tab(n + 1, *fOut);
-    *fOut << "fn build_user_interface(&self, ui_interface: &mut dyn UI<Self::T>) {";
+    *fOut << "pub fn build_user_interface(&self, ui_interface: &mut dyn UI<FaustFloat>) {";
     tab(n + 2, *fOut);
     *fOut << "Self::build_user_interface_static(ui_interface);";
     tab(n + 1, *fOut);
@@ -426,7 +495,7 @@ void RustCodeContainer::produceClass()
     // User interface (static method)
     tab(n + 1, *fOut);
     tab(n + 1, *fOut);
-    *fOut << "fn build_user_interface_static(ui_interface: &mut dyn UI<Self::T>) {";
+    *fOut << "pub fn build_user_interface_static(ui_interface: &mut dyn UI<FaustFloat>) {";
     tab(n + 2, *fOut);
     fCodeProducer.Tab(n + 2);
     RustUIInstVisitor uiCodeproducer(fOut, "", parameterLookup, n + 2);
@@ -437,21 +506,38 @@ void RustCodeContainer::produceClass()
     // Parameter getter/setter
     produceParameterGetterSetter(n + 1, parameterLookup);
 
+    // Control
+    if (gGlobal->gExtControl) {
+        tab(n + 1, *fOut);
+        tab(n + 1, *fOut);
+        *fOut << "pub fn control(&mut self) {";
+        tab(n + 2, *fOut);
+        generateControlDeclarations(&fCodeProducer);
+        back(1, *fOut);
+        *fOut << "}";
+    }
+
     // Compute
-    generateCompute(n + 1);
+    if (gGlobal->gOneSample) {
+        generateComputeFrame(n + 1);
+    } else if (gGlobal->gInPlace) {
+        generateComputeIO(n + 1);
+    } else {
+        generateCompute(n + 1);
+    }
 
     tab(n, *fOut);
     *fOut << "}" << endl;
     tab(n, *fOut);
-
-    // Generate user interface macros if needed
-    printMacros(*fOut, n);
+    if (!gGlobal->gRustNoTraitSwitch) {
+        produceFaustDspBlob();
+    }
 }
 
 void RustCodeContainer::produceMetadata(int n)
 {
     tab(n, *fOut);
-    *fOut << "fn metadata(&self, m: &mut dyn Meta) { ";
+    *fOut << "pub fn metadata(&self, m: &mut dyn Meta) { ";
 
     // We do not want to accumulate metadata from all hierachical levels, so the upper level only is
     // kept
@@ -496,7 +582,7 @@ void RustCodeContainer::produceParameterGetterSetter(int tabs, map<string, int>
     // Add `get_param`
     tab(tabs, *fOut);
     tab(tabs, *fOut);
-    *fOut << "fn get_param(&self, param: ParamIndex) -> Option<Self::T> {";
+    *fOut << "pub fn get_param(&self, param: ParamIndex) -> Option<FaustFloat> {";
     tab(tabs + 1, *fOut);
     *fOut << "match param.0 {";
     for (const auto& paramPair : parameterLookup) {
@@ -515,7 +601,7 @@ void RustCodeContainer::produceParameterGetterSetter(int tabs, map<string, int>
     // Add `set_param`
     tab(tabs, *fOut);
     tab(tabs, *fOut);
-    *fOut << "fn set_param(&mut self, param: ParamIndex, value: Self::T) {";
+    *fOut << "pub fn set_param(&mut self, param: ParamIndex, value: FaustFloat) {";
     tab(tabs + 1, *fOut);
     *fOut << "match param.0 {";
     for (const auto& paramPair : parameterLookup) {
@@ -532,6 +618,75 @@ void RustCodeContainer::produceParameterGetterSetter(int tabs, map<string, int>
     *fOut << "}";
 }
 
+void RustCodeContainer::generateComputeHeader(int n, std::ostream* fOut)
+{
+    // Compute "compute" declaration
+    tab(n, *fOut);
+    *fOut << "pub fn compute(";
+    tab(n + 1, *fOut);
+    *fOut << "&mut self,";
+    tab(n + 1, *fOut);
+    *fOut << "count: usize,";
+    tab(n + 1, *fOut);
+    *fOut << "inputs: &[impl AsRef<[FaustFloat]>],";
+    tab(n + 1, *fOut);
+    *fOut << "outputs: &mut[impl AsMut<[FaustFloat]>],";
+    tab(n, *fOut);
+    *fOut << ") {";
+    tab(n + 1, *fOut);
+}
+
+void RustCodeContainer::generateComputeIOHeader(int n, std::ostream* fOut)
+{
+    // Compute "compute" declaration
+    tab(n, *fOut);
+    *fOut << "pub fn compute(&mut self, count: usize, mut ios: &mut [impl AsMut<[FaustFloat]>]) {";
+    tab(n + 1, *fOut);
+}
+
+void RustCodeContainer::generateComputeFrame(int n)
+{
+    tab(n, *fOut);
+    tab(n, *fOut);
+    *fOut << "pub fn frame(&mut self, inputs: &[&FaustFloat], ";
+    *fOut << "outputs: &mut [&mut FaustFloat]) {";
+
+    for (int i = 0; i < fNumInputs; i++) {
+        tab(n + 1, *fOut);
+        *fOut << "let input" << i << " = inputs[" << i << "];";
+    };
+
+    for (int i = 0; i < fNumOutputs; i++) {
+        tab(n + 1, *fOut);
+        *fOut << "let (nextoutput, outputs): (&mut [&mut f64], &mut [&mut f64]) = "
+                 "outputs.split_at_mut(1);";
+        tab(n + 1, *fOut);
+        *fOut << "let output" << i << ": &mut FaustFloat = nextoutput[0];";
+    };
+
+    fCodeProducer.Tab(n + 1);
+
+    tab(n + 1, *fOut);
+    generateComputeBlock(&fCodeProducer);
+
+    tab(n + 1, *fOut);
+    *fOut << "// generateOneSample";
+    tab(n + 1, *fOut);
+    // Generates one sample computation
+    BlockInst* block = fCurLoop->generateOneSample();
+    block->accept(&fCodeProducer);
+
+    /*
+        // TODO : atomic switch
+        // Currently for soundfile management
+        // also for temp vars
+        */
+    generatePostComputeBlock(&fCodeProducer);
+    tab(n, *fOut);
+    *fOut << "}";
+    tab(n, *fOut);
+}
+
 // Scalar
 RustScalarCodeContainer::RustScalarCodeContainer(const string& name, int numInputs, int numOutputs,
                                                  std::ostream* out, int sub_container_type)
@@ -544,14 +699,10 @@ void RustScalarCodeContainer::generateCompute(int n)
 {
     // Generates declaration
     tab(n, *fOut);
-    tab(n, *fOut);
-    *fOut << "fn compute("
-          << subst("&mut self, $0: i32, inputs: &[&[Self::T]], outputs: &mut[&mut[Self::T]]) {",
-                   fFullCount);
+    generateComputeHeader(n, fOut);
     tab(n + 1, *fOut);
     fCodeProducer.Tab(n + 1);
 
-    // Generates local variables declaration and setup
     generateComputeBlock(&fCodeProducer);
 
     // Generates one single scalar loop
@@ -566,9 +717,37 @@ void RustScalarCodeContainer::generateCompute(int n)
     loop->accept(&fCodeProducer);
 
     // Currently for soundfile management
+    // and for temp vars
     generatePostComputeBlock(&fCodeProducer);
 
-    back(1, *fOut);
+    tab(n, *fOut);
+    *fOut << "}" << endl;
+}
+
+void RustScalarCodeContainer::generateComputeIO(int n)
+{
+    // Generates declaration
+    tab(n, *fOut);
+    generateComputeIOHeader(n, fOut);
+    tab(n + 1, *fOut);
+    fCodeProducer.Tab(n + 1);
+
+    generateComputeBlock(&fCodeProducer);
+
+    // Generates one single scalar loop
+    std::vector<std::string> iterators;
+    int                      num_buffers = max(fNumInputs, fNumOutputs);
+    for (int i = 0; i < num_buffers; ++i) {
+        iterators.push_back("ios" + std::to_string(i));
+    }
+    IteratorForLoopInst* loop = fCurLoop->generateSimpleScalarLoop(iterators);
+    loop->accept(&fCodeProducer);
+
+    // Currently for soundfile management
+    // and for temp vars
+    generatePostComputeBlock(&fCodeProducer);
+
+    tab(n, *fOut);
     *fOut << "}" << endl;
 }
 
@@ -593,9 +772,7 @@ void RustVectorCodeContainer::generateCompute(int n)
     tab(n, *fOut);
     *fOut << "#[allow(unused_mut)]";
     tab(n, *fOut);
-    *fOut << "fn compute("
-          << subst("&mut self, $0: i32, inputs: &[&[Self::T]], outputs: &mut[&mut[Self::T]]) {",
-                   fFullCount);
+    generateComputeHeader(n, fOut);
     tab(n + 1, *fOut);
     fCodeProducer.Tab(n + 1);
 
@@ -661,10 +838,7 @@ void RustOpenMPCodeContainer::generateCompute(int n)
     generateComputeFunctions(&fCodeProducer);
 
     // Compute declaration
-    tab(n, *fOut);
-    *fOut << "fn compute("
-          << subst("&mut self, $0: i32, inputs: &[&[Self::T]], outputs: &mut[&mut[Self::T]]) {",
-                   fFullCount);
+    generateComputeHeader(n, fOut);
     tab(n + 1, *fOut);
     fCodeProducer.Tab(n + 1);
 
@@ -696,6 +870,7 @@ void RustWorkStealingCodeContainer::generateCompute(int n)
     // Generates "computeThread" code
     // Note that users either have to adjust the trait in their architecture file.
     // Alternatively we would have to attach this method to the impl, not the trait.
+    // We moved the method back to the impl.
     tab(n, *fOut);
     *fOut << "pub fn compute_thread(" << fKlassName << "&mut self, num_thread: i32) {";
     tab(n + 1, *fOut);
@@ -706,12 +881,8 @@ void RustWorkStealingCodeContainer::generateCompute(int n)
 
     tab(n, *fOut);
     *fOut << "}" << endl;
+    generateComputeHeader(n, fOut);
 
-    // Compute "compute" declaration
-    tab(n, *fOut);
-    *fOut << "fn compute("
-          << subst("&mut self, $0: i32, inputs: &[&[Self::T]], outputs: &mut[&mut[Self::T]]) {",
-                   fFullCount);
     tab(n + 1, *fOut);
     fCodeProducer.Tab(n + 1);
 
