@@ -136,11 +136,7 @@ itv::interval_algebra gAlgebra;
 global::global()
     : TABBER(1), gLoopDetector(1024, 400), gStackOverflowDetector(MAX_STACK_SIZE), gNextFreeColor(1)
 {
-    if (global::isDebug("FAUST_DTREE")) {
-        CDTree::init();
-    } else {
-        CTree::init();
-    }
+    CTree::init();
     Symbol::init();
 
     // Part of the state that needs to be initialized between consecutive calls to Box/Signal API
@@ -451,11 +447,13 @@ void global::reset()
     gGroupTaskSwitch = false;
     gFunTaskSwitch   = false;
 
-    gUIMacroSwitch = false;
-    gDumpNorm      = -1;
-    gFTZMode       = 0;
-    gRangeUI       = false;
-    gFreezeUI      = false;
+    gUIMacroSwitch     = false;
+    gRustNoTraitSwitch = false;
+
+    gDumpNorm = -1;
+    gFTZMode  = 0;
+    gRangeUI  = false;
+    gFreezeUI = false;
 
     gFloatSize      = 1;             // -single by default
     gFixedPointSize = AP_INT_MAX_W;  // Special -1 value will be used to generate fixpoint_t type
@@ -996,9 +994,6 @@ Typed::VarType global::getVarType(const string& name)
 
 global::~global()
 {
-    if (global::isDebug("FAUST_DTREE")) {
-        CDTree::cleanup();
-    }
     Garbageable::cleanup();
     BasicTyped::cleanup();
     DeclareVarInst::cleanup();
@@ -1371,6 +1366,10 @@ bool global::processCmdline(int argc, const char* argv[])
             gUIMacroSwitch = true;
             i += 1;
 
+        } else if (isCmd(argv[i], "-rnt", "--rust-no-faustdsp-trait")) {
+            gRustNoTraitSwitch = true;
+            i += 1;
+
         } else if (isCmd(argv[i], "-t", "--timeout") && (i + 1 < argc)) {
             gTimeout = std::atoi(argv[i + 1]);
             i += 2;
@@ -1662,6 +1661,15 @@ bool global::processCmdline(int argc, const char* argv[])
     // Check options coherency
     // ========================
 
+    if (gRustNoTraitSwitch && gOutputLang != "rust") {
+        throw faustexception("ERROR : '-rnt' option can only be used with rust\n");
+    }
+
+    if (!gRustNoTraitSwitch && gInPlace && gOutputLang == "rust") {
+        throw faustexception(
+            "ERROR : for 'rust' the '-inpl' flag must be combined with '-rnt' flag\n");
+    }
+
     if (gInPlace && gVectorSwitch) {
         throw faustexception("ERROR : '-inpl' option can only be used in scalar mode\n");
     }
@@ -1672,9 +1680,17 @@ bool global::processCmdline(int argc, const char* argv[])
     }
 #endif
     if (gOneSample && gOutputLang != "cpp" && gOutputLang != "c" && gOutputLang != "dlang" &&
-        !startWith(gOutputLang, "cmajor") && gOutputLang != "fir") {
+        !startWith(gOutputLang, "cmajor") && gOutputLang != "fir" && gOutputLang != "rust") {
         throw faustexception(
-            "ERROR : '-os' option cannot only be used with 'cpp', 'c', 'fir' or 'cmajor' "
+            "ERROR : '-os' option can only be used with 'cpp', 'c', 'cmajor', 'dlang', 'fir' or "
+            "'rust'"
+            "backends\n");
+    }
+
+    if (gExtControl && gOutputLang != "cpp" && gOutputLang != "c" && gOutputLang != "cmajor" &&
+        gOutputLang != "rust") {
+        throw faustexception(
+            "ERROR : '-ec' option can only be used with 'cpp', 'c', 'cmajor' or 'rust' "
             "backends\n");
     }
 
@@ -1723,8 +1739,8 @@ bool global::processCmdline(int argc, const char* argv[])
     }
 
     // gInlinetable check
-    if (gInlineTable && (gOutputLang != "cpp" && gOutputLang != "c")) {
-        throw faustexception("ERROR : -it can only be used with 'cpp' and 'c' backends\n");
+    if (gInlineTable && (gOutputLang != "cpp" && gOutputLang != "c" && gOutputLang != "llvm")) {
+        throw faustexception("ERROR : -it can only be used with 'cpp', 'c' and 'llvm' backends\n");
     }
 
     // gMemoryManager check
@@ -2033,6 +2049,10 @@ static void enumBackends(ostream& out)
     out << dspto << "Rust" << endl;
 #endif
 
+#ifdef SDF3_BUILD
+    out << dspto << "SDF3" << endl;
+#endif
+
 #ifdef TEMPLATE_BUILD
     out << dspto << "Template" << endl;
 #endif
@@ -2104,6 +2124,10 @@ string global::printHelp()
          << "-uim      --user-interface-macros       add user interface macro definitions to the "
             "output code."
          << endl;
+    sstr << tab
+         << "-rnt      --rust-no-faustdsp-trait      (Rust only) Don't generate FaustDsp trait "
+            "implmentation."
+         << endl;
     sstr << tab << "-xml                                    generate an XML description file."
          << endl;
     sstr << tab << "-json                                   generate a JSON description file."
@@ -2121,7 +2145,7 @@ string global::printHelp()
          << "                                        'lang' should be c, cpp (default), cmajor, "
             "codebox, csharp, "
             "dlang, fir, interp, java, jax, jsfx, julia, llvm, "
-            "ocpp, rust, vhdl or wast/wasm."
+            "ocpp, rust, sdf3, vhdl or wast/wasm."
          << endl;
 #endif
     sstr << tab
@@ -2431,6 +2455,10 @@ string global::printHelp()
     sstr << tab
          << "-norm       --normalized-form           print signals in normalized form and exit."
          << endl;
+    sstr << tab
+         << "-norm1      --normalized-form1          print signals in normalized form with IDs for "
+            "shared sub-expressions and exit."
+         << endl;
     sstr << tab
          << "-me         --math-exceptions           check / for 0 as denominator and remainder, "
             "fmod, sqrt, log10, "
@@ -2477,18 +2505,10 @@ string global::printHelp()
          << endl;
     sstr << tab << "FAUST_DEBUG      = FAUST_LLVM2          print LLVM IR after optimisation."
          << endl;
+    sstr << tab << "FAUST_DEBUG      = FIR_PRINTER          print FIR after generation." << endl;
     sstr << tab
          << "FAUST_DEBUG      = FAUST_LLVM_NO_FM     deactivate fast-math optimisation in LLVM IR."
          << endl;
-    sstr << tab
-         << "FAUST_DEBUG      = FAUST_DTREE          successive tree pointer allocation to "
-            "guaranty "
-            "deterministic compilation."
-         << endl;
-    sstr << tab
-         << "FAUST_DTREE_SIZE = <num>                to set the size of each array of successive "
-            "tree pointers in FAUST_DTREE mode."
-         << endl;
     sstr << tab << "FAUST_OPT        = FAUST_SIG_NO_NORM    deactivate signal normalisation."
          << endl;
 
@@ -2639,7 +2659,10 @@ void Garbageable::operator delete[](void* ptr)
     free(ptr);
 }
 
-// Threaded calls API
+/*
+    Threaded calls API: the compilation code is executed in a separate
+    thread so that the stack size can be raised to MAX_STACK_SIZE.
+ */
 void callFun(threaded_fun fun, void* arg)
 {
 #if defined(EMCC)
@@ -2661,3 +2684,4 @@ void callFun(threaded_fun fun, void* arg)
     faustassert(pthread_attr_destroy(&attr) == 0);
 #endif
 }
+
