@@ -1,11 +1,11 @@
 /* Copyright 2023 Yann ORLAREY
- * 
+ *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -24,14 +24,16 @@ namespace itv {
 //------------------------------------------------------------------------------------------
 // negation, invert sign of an interval
 
-interval interval_algebra::Neg(const interval& x) const
+interval interval_algebra::Neg(const interval& x)
 {
-    if (x.isEmpty()) return {};
+    if (x.isEmpty()) {
+        return empty();
+    }
 
-    return {-x.hi(), -x.lo()};
+    return {-x.hi(), -x.lo(), x.lsb()};
 }
 
-void interval_algebra::testNeg() const
+void interval_algebra::testNeg()
 {
     check("test algebra Neg", Neg(interval(-1, 1)), interval(-1, 1));
     check("test algebra Neg", Neg(interval(-10, 1)), interval(-1, 10));
